@@ -24,12 +24,11 @@ use solana_client::{
     pubsub_client::PubsubClient,
     rpc_client::{GetConfirmedSignaturesForAddress2Config, RpcClient},
     rpc_config::{
-        RpcAccountInfoConfig, RpcConfirmedBlockConfig, RpcConfirmedTransactionConfig,
-        RpcGetVoteAccountsConfig, RpcLargestAccountsConfig, RpcLargestAccountsFilter,
-        RpcProgramAccountsConfig, RpcTransactionLogsConfig, RpcTransactionLogsFilter,
+        RpcAccountInfoConfig, RpcBlockConfig, RpcLargestAccountsConfig, RpcLargestAccountsFilter,
+        RpcProgramAccountsConfig, RpcTransactionConfig, RpcTransactionLogsConfig,
+        RpcTransactionLogsFilter,
     },
     rpc_filter,
-    rpc_request::DELINQUENT_VALIDATOR_SLOT_DISTANCE,
     rpc_response::SlotInfo,
 };
 use solana_remote_wallet::remote_wallet::RemoteWalletManager;
@@ -47,7 +46,9 @@ use solana_sdk::{
     rent::Rent,
     rpc_port::DEFAULT_RPC_PORT_STR,
     signature::Signature,
-    slot_history, system_instruction, system_program,
+    slot_history,
+    stake::{self, state::StakeState},
+    system_instruction, system_program,
     sysvar::{
         self,
         slot_history::SlotHistory,
@@ -56,7 +57,6 @@ use solana_sdk::{
     timing,
     transaction::Transaction,
 };
-use solana_stake_program::stake_state::StakeState;
 use solana_transaction_status::UiTransactionEncoding;
 use solana_vote_program::vote_state::VoteState;
 use std::{
@@ -122,7 +122,7 @@ impl ClusterQuerySubCommands for App<'_, '_> {
                         .long("our-localhost")
                         .takes_value(false)
                         .value_name("PORT")
-                        .default_value(&DEFAULT_RPC_PORT_STR)
+                        .default_value(DEFAULT_RPC_PORT_STR)
                         .validator(is_port)
                         .help("Guess Identity pubkey and validator rpc node assuming local (possibly private) validator"),
                 )
@@ -176,7 +176,7 @@ impl ClusterQuerySubCommands for App<'_, '_> {
                     .takes_value(true)
                     .value_name("EPOCH")
                     .validator(is_epoch)
-                    .help("Epoch to show leader schedule for. [default: current]")
+                    .help("Epoch to show leader schedule for. (default: current)")
             )
         )
         .subcommand(
@@ -382,25 +382,6 @@ impl ClusterQuerySubCommands for App<'_, '_> {
                         ])
                         .default_value("stake")
                         .help("Sort order (does not affect JSON output)"),
-                )
-                .arg(
-                    Arg::with_name("keep_unstaked_delinquents")
-                        .long("keep-unstaked-delinquents")
-                        .takes_value(false)
-                        .help("Don't discard unstaked, delinquent validators")
-                )
-                .arg(
-                    Arg::with_name("delinquent_slot_distance")
-                        .long("delinquent-slot-distance")
-                        .takes_value(true)
-                        .value_name("SLOT_DISTANCE")
-                        .validator(is_slot)
-                        .help(
-                            concatcp!(
-                                "Minimum slot distance from the tip to consider a validator delinquent. [default: ",
-                                DELINQUENT_VALIDATOR_SLOT_DISTANCE,
-                                "]",
-                        ))
                 ),
         )
         .subcommand(
@@ -636,8 +617,6 @@ pub fn parse_show_validators(matches: &ArgMatches<'_>) -> Result<CliCommandInfo,
     let use_lamports_unit = matches.is_present("lamports");
     let number_validators = matches.is_present("number");
     let reverse_sort = matches.is_present("reverse");
-    let keep_unstaked_delinquents = matches.is_present("keep_unstaked_delinquents");
-    let delinquent_slot_distance = value_of(matches, "delinquent_slot_distance");
 
     let sort_order = match value_t_or_exit!(matches, "sort", String).as_str() {
         "delinquent" => CliValidatorsSortOrder::Delinquent,
@@ -658,8 +637,6 @@ pub fn parse_show_validators(matches: &ArgMatches<'_>) -> Result<CliCommandInfo,
             sort_order,
             reverse_sort,
             number_validators,
-            keep_unstaked_delinquents,
-            delinquent_slot_distance,
         },
         signers: vec![],
     })
@@ -961,19 +938,18 @@ pub fn process_fees(
                 *recent_blockhash,
                 fee_calculator.lamports_per_signature,
                 None,
-                None,
             )
         } else {
             CliFees::none()
         }
     } else {
-        let result = rpc_client.get_fees_with_commitment(config.commitment)?;
+        let result = rpc_client.get_recent_blockhash_with_commitment(config.commitment)?;
+        let (recent_blockhash, fee_calculator, last_valid_slot) = result.value;
         CliFees::some(
             result.context.slot,
-            result.value.blockhash,
-            result.value.fee_calculator.lamports_per_signature,
-            None,
-            Some(result.value.last_valid_block_height),
+            recent_blockhash,
+            fee_calculator.lamports_per_signature,
+            Some(last_valid_slot),
         )
     };
     Ok(config.output_format.formatted_string(&fees))
@@ -1052,12 +1028,12 @@ pub fn process_get_block(
     };
 
     let encoded_confirmed_block = rpc_client
-        .get_confirmed_block_with_config(
+        .get_block_with_config(
             slot,
-            RpcConfirmedBlockConfig {
+            RpcBlockConfig {
                 encoding: Some(UiTransactionEncoding::Base64),
                 commitment: Some(CommitmentConfig::confirmed()),
-                ..RpcConfirmedBlockConfig::default()
+                ..RpcBlockConfig::default()
             },
         )?
         .into();
@@ -1100,15 +1076,9 @@ pub fn process_get_epoch_info(rpc_client: &RpcClient, config: &CliConfig) -> Pro
             (secs as u64).saturating_mul(1000).checked_div(slots)
         })
         .unwrap_or(clock::DEFAULT_MS_PER_SLOT);
-    let start_block_time = rpc_client
-        .get_block_time(epoch_info.absolute_slot - epoch_info.slot_index)
-        .ok();
-    let current_block_time = rpc_client.get_block_time(epoch_info.absolute_slot).ok();
     let epoch_info = CliEpochInfo {
         epoch_info,
         average_slot_time_ms,
-        start_block_time,
-        current_block_time,
     };
     Ok(config.output_format.formatted_string(&epoch_info))
 }
@@ -1215,7 +1185,7 @@ pub fn process_show_block_production(
                 start_slot = minimum_ledger_slot;
             }
 
-            let confirmed_blocks = rpc_client.get_confirmed_blocks(start_slot, Some(end_slot))?;
+            let confirmed_blocks = rpc_client.get_blocks(start_slot, Some(end_slot))?;
             (confirmed_blocks, start_slot)
         };
 
@@ -1738,7 +1708,7 @@ pub fn process_show_stakes(
         }
     }
     let all_stake_accounts = rpc_client
-        .get_program_accounts_with_config(&solana_stake_program::id(), program_accounts_config)?;
+        .get_program_accounts_with_config(&stake::program::id(), program_accounts_config)?;
     let stake_history_account = rpc_client.get_account(&stake_history::id())?;
     let clock_account = rpc_client.get_account(&sysvar::clock::id())?;
     let clock: Clock = from_account(&clock_account).ok_or_else(|| {
@@ -1816,17 +1786,11 @@ pub fn process_show_validators(
     validators_sort_order: CliValidatorsSortOrder,
     validators_reverse_sort: bool,
     number_validators: bool,
-    keep_unstaked_delinquents: bool,
-    delinquent_slot_distance: Option<Slot>,
 ) -> ProcessResult {
     let progress_bar = new_spinner_progress_bar();
     progress_bar.set_message("Fetching vote accounts...");
     let epoch_info = rpc_client.get_epoch_info()?;
-    let vote_accounts = rpc_client.get_vote_accounts_with_config(RpcGetVoteAccountsConfig {
-        keep_unstaked_delinquents: Some(keep_unstaked_delinquents),
-        delinquent_slot_distance,
-        ..RpcGetVoteAccountsConfig::default()
-    })?;
+    let vote_accounts = rpc_client.get_vote_accounts()?;
 
     progress_bar.set_message("Fetching block production...");
     let skip_rate: HashMap<_, _> = rpc_client
@@ -1925,40 +1889,14 @@ pub fn process_show_validators(
         entry.delinquent_active_stake += validator.activated_stake;
     }
 
-    let validators: Vec<_> = current_validators
-        .into_iter()
-        .chain(delinquent_validators.into_iter())
-        .collect();
-
-    let (average_skip_rate, average_stake_weighted_skip_rate) = {
-        let mut skip_rate_len = 0;
-        let mut skip_rate_sum = 0.;
-        let mut skip_rate_weighted_sum = 0.;
-        for validator in validators.iter() {
-            if let Some(skip_rate) = validator.skip_rate {
-                skip_rate_sum += skip_rate;
-                skip_rate_len += 1;
-                skip_rate_weighted_sum += skip_rate * validator.activated_stake as f64;
-            }
-        }
-
-        if skip_rate_len > 0 && total_active_stake > 0 {
-            (
-                skip_rate_sum / skip_rate_len as f64,
-                skip_rate_weighted_sum / total_active_stake as f64,
-            )
-        } else {
-            (100., 100.) // Impossible?
-        }
-    };
-
     let cli_validators = CliValidators {
         total_active_stake,
         total_current_stake,
         total_delinquent_stake,
-        validators,
-        average_skip_rate,
-        average_stake_weighted_skip_rate,
+        validators: current_validators
+            .into_iter()
+            .chain(delinquent_validators.into_iter())
+            .collect(),
         validators_sort_order,
         validators_reverse_sort,
         number_validators,
@@ -1977,7 +1915,7 @@ pub fn process_transaction_history(
     limit: usize,
     show_transactions: bool,
 ) -> ProcessResult {
-    let results = rpc_client.get_confirmed_signatures_for_address2_with_config(
+    let results = rpc_client.get_signatures_for_address_with_config(
         address,
         GetConfirmedSignaturesForAddress2Config {
             before,
@@ -2016,9 +1954,9 @@ pub fn process_transaction_history(
 
         if show_transactions {
             if let Ok(signature) = result.signature.parse::<Signature>() {
-                match rpc_client.get_confirmed_transaction_with_config(
+                match rpc_client.get_transaction_with_config(
                     &signature,
-                    RpcConfirmedTransactionConfig {
+                    RpcTransactionConfig {
                         encoding: Some(UiTransactionEncoding::Base64),
                         commitment: Some(CommitmentConfig::confirmed()),
                     },
