@@ -17,10 +17,11 @@ use solana_sdk::{
     nonce::State as NonceState,
     pubkey::Pubkey,
     signature::{keypair_from_seed, Keypair, Signer},
-};
-use solana_stake_program::{
-    stake_instruction::LockupArgs,
-    stake_state::{Lockup, StakeAuthorize, StakeState},
+    stake::{
+        self,
+        instruction::LockupArgs,
+        state::{Lockup, StakeAuthorize, StakeState},
+    },
 };
 
 #[test]
@@ -139,7 +140,7 @@ fn test_seed_stake_delegation_and_deactivation() {
     let stake_address = Pubkey::create_with_seed(
         &config_validator.signers[0].pubkey(),
         "hi there",
-        &solana_stake_program::id(),
+        &stake::program::id(),
     )
     .expect("bad seed");
 
@@ -608,6 +609,7 @@ fn test_stake_authorize() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     process_command(&config).unwrap();
     let stake_account = rpc_client.get_account(&stake_account_pubkey).unwrap();
@@ -638,6 +640,7 @@ fn test_stake_authorize() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     process_command(&config).unwrap();
     let stake_account = rpc_client.get_account(&stake_account_pubkey).unwrap();
@@ -663,6 +666,7 @@ fn test_stake_authorize() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     process_command(&config).unwrap();
     let stake_account = rpc_client.get_account(&stake_account_pubkey).unwrap();
@@ -688,6 +692,7 @@ fn test_stake_authorize() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     config_offline.output_format = OutputFormat::JsonCompact;
     let sign_reply = process_command(&config_offline).unwrap();
@@ -706,6 +711,7 @@ fn test_stake_authorize() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     process_command(&config).unwrap();
     let stake_account = rpc_client.get_account(&stake_account_pubkey).unwrap();
@@ -756,6 +762,7 @@ fn test_stake_authorize() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     let sign_reply = process_command(&config_offline).unwrap();
     let sign_only = parse_sign_only_reply_string(&sign_reply);
@@ -778,6 +785,7 @@ fn test_stake_authorize() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     process_command(&config).unwrap();
     let stake_account = rpc_client.get_account(&stake_account_pubkey).unwrap();
@@ -881,6 +889,7 @@ fn test_stake_authorize_with_fee_payer() {
         memo: None,
         fee_payer: 1,
         custodian: None,
+        no_wait: false,
     };
     process_command(&config).unwrap();
     // `config` balance has not changed, despite submitting the TX
@@ -902,6 +911,7 @@ fn test_stake_authorize_with_fee_payer() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     config_offline.output_format = OutputFormat::JsonCompact;
     let sign_reply = process_command(&config_offline).unwrap();
@@ -920,6 +930,7 @@ fn test_stake_authorize_with_fee_payer() {
         memo: None,
         fee_payer: 0,
         custodian: None,
+        no_wait: false,
     };
     process_command(&config).unwrap();
     // `config`'s balance again has not changed
@@ -1547,6 +1558,6 @@ fn test_offline_nonced_create_stake_account_and_withdraw() {
     };
     process_command(&config).unwrap();
     let seed_address =
-        Pubkey::create_with_seed(&stake_pubkey, seed, &solana_stake_program::id()).unwrap();
+        Pubkey::create_with_seed(&stake_pubkey, seed, &stake::program::id()).unwrap();
     check_recent_balance(50_000, &rpc_client, &seed_address);
 }
